@@ -19,11 +19,11 @@ from spanner_orm.admin import schema
 
 
 class TableSchema(schema.InformationSchema):
-  """Model for interacting with Spanner column schema table."""
+    """Model for interacting with Spanner column schema table."""
 
-  __table__ = 'information_schema.tables'
-  table_catalog = field.Field(field.String, primary_key=True)
-  table_schema = field.Field(field.String, primary_key=True)
-  table_name = field.Field(field.String, primary_key=True)
-  parent_table_name = field.Field(field.String, nullable=True)
-  on_delete_action = field.Field(field.String, nullable=True)
+    __table__ = "information_schema.tables"
+    table_catalog = field.Field(field.String, primary_key=True)
+    table_schema = field.Field(field.String, primary_key=True)
+    table_name = field.Field(field.String, primary_key=True)
+    parent_table_name = field.Field(field.String, nullable=True)
+    on_delete_action = field.Field(field.String, nullable=True)
